@@ -59,9 +59,9 @@ class PackageData:
 
 def get_pip_list():
     """Return a list of PackageData classes."""
-    pip_freeze = subprocess.check_output(("pip", "freeze")).decode("utf8")
-    pip_freeze = pip_freeze.split("\n")
-    return [PackageData(x) for x in pip_freeze]
+    data = subprocess.check_output(["pip", "list", "--format", "json"])
+    parsed_results = json.loads(data)
+    return [PackageData(f"{x['name']}=={x['version']}") for x in parsed_results]
 
 
 def get_pip_dict():
@@ -100,7 +100,7 @@ def update_requirements_file(file, package_dict):
     # Go line by line and determine if a package needs to be updated
     for line in lines:
         # Simply re-add comments or empty lines
-        if line.startswith("#") or line.startswith("\n"):
+        if bool(line.startswith(("#", "\n", "-r"))):
             replaced_content += line
             continue
 
@@ -147,13 +147,16 @@ def run():
 
 
 def upgrade():
-    """Upgrade packages listed in requirements files."""
+    """
+    Upgrade packages listed in requirements files.
+    EXPERIMENTAL. Do not use in production.
+    """
     requirements_files = find_requirements_files()
     installed_reqs = []
     for file in requirements_files:
         lines = open_requirements(file)
         for line in lines:
-            if line.startswith("#") or line.startswith("\n") or line.startswith("-r"):
+            if bool(line.startswith(("#", "\n", "-r"))):
                 continue
             package = PackageData(line)
             installed_reqs.append(package.name)
